@@ -25,7 +25,7 @@ class Publisher(object):
         LOGGER.info('Publishing message %s', body, **kwargs)
 
         future = self.instance.publish(
-            self.topic_name, json.dumps(body), **kwargs)
+            self.topic_name, json.dumps(body).encode('utf-8'), **kwargs)
 
         def handle_publish_done(future):
             try:
